==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/gco51CSqlSessionContext.h <==
/*!***************************************************************************

  module      : gco51CSqlSessionContext.h

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: C++ SQL-Class   
  description : co51CSqlSessionContext 
				
  
  last changed: 2000-03-08  11:22
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

#ifndef GCO51CSQLSESSIONCONTEXT_H
#define GCO51CSQLSESSIONCONTEXT_H

#ifndef VSP001_H
#include "vsp001.h"
#endif
#ifndef GGG00_H
#include "ggg00.h"
#endif
#ifndef GCO00_H
#include "gco00.h"
#endif
#ifndef __HEO381_H
#include "heo381.h"
#endif
#ifndef GGG251_H
#include "ggg251.h"
#endif
#ifndef GCO502SQLOPT_H
#include "gco502SqlOpt.h"
#endif
#ifndef GCO519CERRORHANDLING_H
#include "gco519CErrorHandling.h"
#endif
#ifndef __vco03_h__
#include "livecachetypes.h" /* no check*/
#endif
#ifndef HSP81_H
#include "hsp81.h"
#endif

class SqlHandle;
class co521CSqlStmt;
class cin203_RequestPacket;
struct IliveCacheSink;
class SQL;

struct structSqlCa 
{
  structSqlCa()	
  {
    this->sqlCAInit();
  };
  
  void sqlCAInit(const unsigned char reqType = '\0') 
  {
    sqlrescount = 0;
    sqlerrpos   = 0;
    sqlcode		  = 0;
    memset(sqlwarn,' ',sizeof(sqlwarn));
    sqlerrml	  = 0;
    sqlerrmt    = reqType;
    memset(sqlerrmc,'\0',sizeof(sqlerrmc) );
    memset(sqlerrmuc,'\0',sizeof(sqlerrmuc));
    memset(sqlstate,' ',sizeof(sqlstate) - 1);
    sqlstate[sizeof(sqlstate) - 1] = '\0';
  };
  
  int             sqlrescount;
  int             sqlerrpos;
  short		        sqlcode;
  char		        sqlwarn [16];
  short		        sqlerrml;
  unsigned char   sqlerrmt;           // 0=Ascii; 1=Unicode 
  char		        sqlerrmc  [81];     // 0 terminated char
  DbpTypeUnicode  sqlerrmuc [162];    // 0x0000 terminated char
  char	  	      sqlstate[6];        // 0 terminated
};

class co51CSqlSessionContext : public co519CErrorHandling
{
private:
  class SessionHeap : public ceo381_Heap 
  {
  public :
    SessionHeap();
    virtual teo381_ChunkPtr GetMem(size_t sz);
    virtual void FreeMem(teo381_ChunkPtr p);
    virtual ~SessionHeap(); // required by sun compiler
  };
  SessionHeap           m_heap;
  cgg251DCList<co521CSqlStmt*,ceo381_Heap> m_CSqlStmtDir;
  SqlHandle&            m_sqlhandle;
  structSqlCa           m_sqlca;
  tsp00_Int4            m_request_packet_size;
  tsp1_packet*          m_request_packet; 
  tsp1_packet*          m_reply_packet; 
  tsp1_sqlmode	        m_sqlmode;
  boolean               m_deleteSelf;
#if defined (EXT_CLIENT_SQL)
  int                   m_connection;
  //  char*                 m_hostname;
  //  char*                 m_dbname;
#endif
  
  IliveCacheSink* initSession(const unsigned char reqType = '\0');
  int executeDBRequest( IliveCacheSink* pILCSink, cin203_RequestPacket &reqPacket );
  int executeImmediateSQL( IliveCacheSink* pILCSink, co521CSqlStmt* pSqlStmt );
  int executePreparedSQL( IliveCacheSink* pILCSink, co521CSqlStmt* pSqlStmt );
  int executeLongInput( IliveCacheSink* pILCSink, cin203_RequestPacket &reqPacket, 
    co521CSqlStmt* pSqlStmt );
  int executeLongOutput( IliveCacheSink* pILCSink, cin203_RequestPacket &reqPacket, 
    co521CSqlStmt* pSqlStmt );
  
  public:
    co51CSqlSessionContext( SqlHandle& pHandle );
    ~co51CSqlSessionContext();
    void  createSqlStmt( SQL& sql, const char *stmt );
    void  createSqlStmt( SQL& sql, const DbpTypeUnicode *stmt );
    void  dropSqlStmt( co521CSqlStmt* pSqlStmt );
    int   executeSqlStmt( co521CSqlStmt* pSqlStmt );
    int   prepareSqlStmt( co521CSqlStmt* pSqlStmt, const pasbool parsingAgain = false );
    void* operator new( size_t sz );
    void  operator delete (void* p);
    
#if defined (EXT_CLIENT_SQL)
    int		connect (co521CSqlStmt* pSqlStmt, const char* hostname, const char* dbname, 
      const char* user, const char* pwd, const char* isolevel);
#endif
    void  sqlSetMode( const SqlOpt::SqlSessionMode mode );
    void* allocate( size_t sz );
    void  deallocate ( void* p );
    void  deleteSelf ( );
    int   dropParsid( co521CSqlStmt* pSqlStmt );
    void  setErrortext ( int argCount, int len, const char * data );
    void  setResultCount( int data );
    void  setWarnTrunc();
    short sqlCode () const;
    char  sqlWarning (int) const;
    long  sqlErrorPos () const;       
    long  sqlResultCount () const;    
    const char* sqlErrorMsg() const;
    int   sqlIsUnicodeErrMsg() const;
    const DbpTypeUnicode* sqlUnicodeErrorMsg() const;
    const char*	sqlState() const;       
    void  setRtError( tgg00_BasisError e, const char* p1, const char* p2, const char* p3 );
    void  setError( tgg00_BasisError e, const char* p1 );
};

#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/gco51CSqlSessionContext.h <==
/*!***************************************************************************

  module      : gco51CSqlSessionContext.h

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: C++ SQL-Class   
  description : co51CSqlSessionContext 
				
  
  last changed: 2000-03-08  11:22
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

#ifndef GCO51CSQLSESSIONCONTEXT_H
#define GCO51CSQLSESSIONCONTEXT_H

#ifndef VSP001_H
#include "vsp001.h"
#endif
#ifndef GGG00_H
#include "ggg00.h"
#endif
#ifndef GCO00_H
#include "gco00.h"
#endif
#ifndef GGG251_H
#include "ggg251.h"
#endif
#ifndef GCO502SQLOPT_H
#include "gco502SqlOpt.h"
#endif
#ifndef GCO519CERRORHANDLING_H
#include "gco519CErrorHandling.h"
#endif
#ifndef __vco03_h__
#include "livecachetypes.h" /* no check*/
#endif
#ifndef HSP81_H
#include "hsp81.h"
#endif
#if !defined (EXT_CLIENT_SQL)
// hco10.h   is needed because of omsHeap functions
#include "hco10.h"
#include "liveCache/LVC_KernelInterface.hpp"
#include "SAPDBCommon/MemoryManagement/SAPDBMem_IBlockAllocator.hpp"
#include "SAPDBCommon/MemoryManagement/SAPDBMem_RawAllocator.hpp"
#include "CppSQL/SQL_Monitor.hpp"     /* PTS 1120804 */
#endif

/* PTS 1121948 */
#ifndef GCO50SQLHANDLE_H
#include "gco50SqlHandle.h"
#endif

class co521CSqlStmt;
class cin203_RequestPacket;
struct IliveCacheSink;
class SQL;

typedef void (__cdecl * sqlHandler ) ( SqlHandle* p_sqlhandle );     /* PTS 1120804 */

struct structSqlCa 
{
  structSqlCa()	
  {
    this->sqlCAInit();
  };
  
  void sqlCAInit(const unsigned char reqType = '\0') 
  {
    sqlrescount = 0;
    sqlerrpos   = 0;
    sqlcode		  = 0;
    memset(sqlwarn,' ',sizeof(sqlwarn));
    sqlerrml	  = 0;
    sqlerrmt    = reqType;
    memset(sqlerrmc,'\0',sizeof(sqlerrmc) );
    memset(sqlerrmuc,'\0',sizeof(sqlerrmuc));
    memset(sqlstate,' ',sizeof(sqlstate) - 1);
    sqlstate[sizeof(sqlstate) - 1] = '\0';
  };
  
  int             sqlrescount;
  int             sqlerrpos;
  short		        sqlcode;
  char		        sqlwarn [16];
  short		        sqlerrml;
  unsigned char   sqlerrmt;           // 0=Ascii; 1=Unicode 
  char		        sqlerrmc  [81];     // 0 terminated char
  DbpTypeUnicode  sqlerrmuc [162];    // 0x0000 terminated char
  char	  	      sqlstate[6];        // 0 terminated
};

class co51CSqlSessionContext : public co519CErrorHandling
{
private :
  class SessionHeap
  {
# if !defined (EXT_CLIENT_SQL)
  private:
    SAPDBMem_RawAllocator *m_alloc;
# endif
  public :
    SessionHeap();
    ~SessionHeap();
    void* allocate(size_t sz)
    {
#     if defined (EXT_CLIENT_SQL)
      return malloc(sz);
#     else
#     if defined(OMSTST)
      co10_GetKernelInterface()->TestBadAlloc();
#     endif
      return m_alloc->Allocate(sz);
#     endif
    }
    void deallocate(void* p)
    {
#     if defined (EXT_CLIENT_SQL)
      free(p);
#     else
      m_alloc->Deallocate(p);
#     endif
    }
  };
  SessionHeap           m_heap;
  cgg251DCList<co521CSqlStmt*,SessionHeap> m_CSqlStmtDir;
  SqlHandle             m_sqlhandle;              /* PTS 1121948 */
  structSqlCa           m_sqlca;
  tsp00_Int4            m_request_packet_size;
  tsp1_packet*          m_request_packet; 
  tsp1_packet*          m_reply_packet; 
  tsp1_sqlmode	        m_sqlmode;
  boolean               m_deleteSelf;
  int                   m_ref_count;              /* PTS 1120804 */
  sqlHandler            m_sqlhandler;             /* PTS 1120804 */
#if !defined(EXT_CLIENT_SQL)                      /* PTS 1120804 */
  bool                  m_isUnicodeInstance;      /* PTS 1121341 */
  IliveCacheSink*       m_pSink;                  /* PTS 1121948 */
  int                   m_data_len;               /* PTS 1120804 */
  boolean               m_inMethodCallEpilog;     /* PTS 1120804 */
  SQL_Monitor           m_monitor;                /* PTS 1120804 */
  tsp00_KnlIdentifier*  m_curr_method;            /* PTS 1120804 */
# endif                                           /* PTS 1120804 */
#if defined (EXT_CLIENT_SQL)
  int                   m_connection;
  //  char*                 m_hostname;
  //  char*                 m_dbname;
#endif
  
  IliveCacheSink* initSession(const unsigned char reqType = '\0');
  int executeDBRequest( IliveCacheSink* pILCSink, cin203_RequestPacket &reqPacket );
  int executeImmediateSQL( IliveCacheSink* pILCSink, co521CSqlStmt* pSqlStmt );
  int executePreparedSQL( IliveCacheSink* pILCSink, co521CSqlStmt* pSqlStmt );
  int executeLongInput( IliveCacheSink* pILCSink, cin203_RequestPacket &reqPacket, 
    co521CSqlStmt* pSqlStmt );
  int executeLongOutput( IliveCacheSink* pILCSink, cin203_RequestPacket &reqPacket, 
    co521CSqlStmt* pSqlStmt );
# if !defined (EXT_CLIENT_SQL)      /* PTS 1120804 */
  void  monitorRequest(int fc);     /* PTS 1120804 */
# endif                             /* PTS 1120804 */
  
  public:
    co51CSqlSessionContext( SqlHandle& pHandle );
    ~co51CSqlSessionContext();
    void  createSqlStmt( SQL& sql, const char *stmt );
    void  createSqlStmt( SQL& sql, const DbpTypeUnicode *stmt );
    void  dropSqlStmt( co521CSqlStmt* pSqlStmt );
    int   executeSqlStmt( co521CSqlStmt* pSqlStmt );
    int   prepareSqlStmt( co521CSqlStmt* pSqlStmt, const pasbool parsingAgain = false );
    void* operator new( size_t sz );
    void  operator delete (void* p);
    
#if defined (EXT_CLIENT_SQL)
    int		connect (co521CSqlStmt* pSqlStmt, const char* hostname, const char* dbname, 
      const char* user, const char* pwd, const char* isolevel);
#endif
    void  sqlSetMode( const SqlOpt::SqlSessionMode mode );
    void* allocate( size_t sz );
    void  deallocate ( void* p );
    void  deleteSelf ( );
    int   dropParsid( co521CSqlStmt* pSqlStmt );
    void  setErrortext ( int argCount, int len, const char * data );
    void  setResultCount( int data );
    void  setWarnTrunc();
    short sqlCode () const;
    char  sqlWarning (int) const;
    long  sqlErrorPos () const;       
    long  sqlResultCount () const;    
    const char* sqlErrorMsg() const;
    int   sqlIsUnicodeErrMsg() const;
    const DbpTypeUnicode* sqlUnicodeErrorMsg() const;
    const char*	sqlState() const;       
    void  setRtError( tgg00_BasisError e, const char* p1, const char* p2, const char* p3 );
    void  setError( tgg00_BasisError e, const char* p1 );
    void  setHandler(sqlHandler p);                                  /* PTS 1120804 */
    sqlHandler getHandler();                                         /* PTS 1120804 */               
# if !defined (EXT_CLIENT_SQL)                                       /* PTS 1120804 */
    void  setSink(IliveCacheSink * pSink);                           /* PTS 1121948 */
    bool  isUnicodeInstance();                                       /* PTS 1121341 */
    void  incRefCnt();                                               /* PTS 1120804 */
    void  decRefCnt();                                               /* PTS 1120804 */
    SQL_Monitor* getMonitor();                                       /* PTS 1120804 */
    void  setMethodCallEpilog();                                     /* PTS 1120804 */
    void  resetMethodCallEpilog();                                   /* PTS 1120804 */
    void  setCurrMethod(unsigned char* name);                        /* PTS 1120804 */
    void  resetCurrMethod();                                         /* PTS 1120804 */
    bool  getMethodCallMonitorInfo (SqlMonitorData& info) const;     /* PTS 1120804 */
    void  setDataLen(int DataLen);                                   /* PTS 1120804 */
# endif                                                              /* PTS 1120804 */
};

#endif
